@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.5007';
+our $VERSION = '0.5008';
 
 use Moo;
 use strictures 2;
@@ -703,7 +703,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.5007
+version 0.5008
 
 =head1 SYNOPSIS
 
@@ -1248,7 +1248,7 @@ L<https://en.wikipedia.org/wiki/General_MIDI_Level_2#Drum_sounds>
 
 =head1 AUTHOR
 
-Gene Boggs <gene@cpan.org>
+Gene Boggs <gene.boggs@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
